﻿/*==============================================================================
 * Author:深度训练
 * Create time: 2013-07-28
 * Blog Address:http://www.cnblogs.com/wangiqngpei557/
 * Author Description:特定领域软件工程实践；
 *==============================================================================*/
using System;
using System.Collections.Generic;
using System.Linq.Expressions;
using System.Linq;
using Infrastructure.Common.Cache;
using Infrastructure.Common.Validator;

namespace ConsoleApplication1.DomainModel
{
    /// <summary>
    /// Order.
    /// </summary>
    [EntityCache(10, true)]
    [EntityValidator(ValidatorOperationType.All)]
    public class Order
    {
        /// <summary>
        /// Order code.
        /// </summary>
        public string OrderCode { get; set; }

        /// <summary>
        /// Items filed.
        /// </summary>
        private List<Item> items = new List<Item>();
        /// <summary>
        /// Gets items .
        /// </summary>
        public IEnumerable<Item> Items { get { return items; } }

        /// <summary>
        /// Submit order date.
        /// </summary>
        public DateTime SubmitDate { get; set; }

        /// <summary>
        /// Mark <see cref="DomainModel.Order"/> Instance.
        /// </summary>
        /// <param name="orderCode">Order code. </param>
        public Order(string orderCode)
        {
            this.OrderCode = orderCode;
        }

        /// <summary>
        /// Sum items prices.
        /// </summary>
        /// <param name="itemUsingType">item type.</param>
        /// <returns>prices .</returns>
        public double SumPrices(int itemUsingType)
        {
            double resultPrices = 0.00;
            var currentItems = items.GroupBy(item => item.ItemUsingType).Single(group => group.Key == itemUsingType);
            if (currentItems.Count() > 0)
            {
                foreach (var item in currentItems)
                {
                    resultPrices += item.Price;
                }
            }
            return resultPrices;
        }

        /// <summary>
        /// Add item to order.
        /// </summary>
        /// <param name="item">Item.</param>
        /// <returns>bool.</returns>
        public bool AddItem(Item item)
        {
            if (!item.ItemCode.Equals(string.Empty))
            {
                this.items.Add(item);
                return true;
            }
            return false;
        }
    }
}